[llvm-commits] [llvm] r45077 - /llvm/trunk/lib/Transforms/Utils/InlineFunction.cpp

Duncan Sands baldrick at free.fr
Sun Dec 16 13:01:21 PST 2007


Author: baldrick
Date: Sun Dec 16 15:01:21 2007
New Revision: 45077

URL: http://llvm.org/viewvc/llvm-project?rev=45077&view=rev
Log:
Revert this part of r45073 until the verifier is
changed not to reject invoke of inline asm.

Modified:
    llvm/trunk/lib/Transforms/Utils/InlineFunction.cpp

Modified: llvm/trunk/lib/Transforms/Utils/InlineFunction.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/Utils/InlineFunction.cpp?rev=45077&r1=45076&r2=45077&view=diff

==============================================================================
--- llvm/trunk/lib/Transforms/Utils/InlineFunction.cpp (original)
+++ llvm/trunk/lib/Transforms/Utils/InlineFunction.cpp Sun Dec 16 15:01:21 2007
@@ -69,8 +69,9 @@
           if (!isa<CallInst>(I)) continue;
           CallInst *CI = cast<CallInst>(I);
 
-          // If this call cannot unwind, don't convert it to an invoke.
-          if (CI->isNoUnwind())
+          // If this call cannot unwind or is an inline asm, don't
+          // convert it to an invoke.
+          if (CI->isNoUnwind() || isa<InlineAsm>(CI->getCalledValue()))
             continue;
 
           // Convert this function call into an invoke instruction.





More information about the llvm-commits mailing list